@@ -59,25 +59,25 @@ $ABSTRACT = 'Sim::OPT::Sim is the module used by Sim::OPT to launch simulations
 
 sub sim    # This function launch the simulations in ESP-r
 {
-	my $swap = shift; #say $tee "swapINSIM: " . dump($swap);
+	my $swap = shift; 
 	my %dat = %$swap;
-	my @instances = @{ $dat{instances} }; #say "scalar(\@instances): " . scalar(@instances);
-	my $countcase = $dat{countcase}; #say "dump(\$countcase): " . dump($countcase); # IT WILL BE SHADOWED. CUT ZZZ
-	my $countblock = $dat{countblock}; #say "dump(\$countblock): " . dump($countblock); # IT WILL BE SHADOWED. CUT ZZZ			
-	my %dirfiles = %{ $dat{dirfiles} }; #say "dump(\%dirfiles): " . dump(%dirfiles); 
+	my @instances = @{ $dat{instances} }; 
+	my $countcase = $dat{countcase}; 
+	my $countblock = $dat{countblock}; 
+	my %dirfiles = %{ $dat{dirfiles} }; 
 		
-	$configfile = $main::configfile; #say "dump(\$configfile): " . dump($configfile);
-	@varinumbers = @main::varinumbers; #say "dump(\@varinumbers): " . dump(@varinumbers);
+	$configfile = $main::configfile; 
+	@varinumbers = @main::varinumbers; 
 	@mediumiters = @main::mediumiters;
-	@rootnames = @main::rootnames; #say "dump(\@rootnames): " . dump(@rootnames);
-	%vals = %main::vals; #say "dump(\%vals): " . dump(%vals);
+	@rootnames = @main::rootnames; 
+	%vals = %main::vals; 
 	
-	$mypath = $main::mypath;  #say $tee "dumpINSIM(\$mypath): " . dump($mypath);
-	$exeonfiles = $main::exeonfiles; #say $tee "dumpINSIM(\$exeonfiles): " . dump($exeonfiles);
+	$mypath = $main::mypath;  
+	$exeonfiles = $main::exeonfiles; 
 	$generatechance = $main::generatechance; 
 	$file = $main::file;
 	$preventsim = $main::preventsim;
-	$fileconfig = $main::fileconfig; #say $tee "dumpINSIM(\$fileconfig): " . dump($fileconfig); # NOW GLOBAL. TO MAKE IT PRIVATE, FIX PASSING OF PARAMETERS IN CONTRAINTS PROPAGATION SECONDARY SUBROUTINES
+	$fileconfig = $main::fileconfig; 
 	$outfile = $main::outfile;
 	$tofile = $main::tofile;
 	$report = $main::report;
@@ -91,7 +91,7 @@ sub sim    # This function launch the simulations in ESP-r
 	
 	%dowhat = %main::dowhat;
 
-	%simtitles = %main::simtitles; #say "dumpINSIM(\%simtitles): " . dump(%simtitles);
+	%simtitles = %main::simtitles; 
 	%retrievedata = %main::retrievedata;
 	@keepcolumns = @main::keepcolumns;
 	@weights = @main::weights;
@@ -109,8 +109,8 @@ sub sim    # This function launch the simulations in ESP-r
 	@filter_columns = @main::filter_columns;
 	%vals = %main::vals;
 	
-	my @simcases = @{ $dirfiles{simcases} }; #say "dump(\@simcases): " . dump(@simcases);
-	my @simstruct = @{ $dirfiles{simstruct} }; #say "dump(\@simstruct): " . dump(@simstruct);
+	my @simcases = @{ $dirfiles{simcases} }; 
+	my @simstruct = @{ $dirfiles{simstruct} }; 
 	my @morphcases = @{ $dirfiles{morphcases} };
 	my @morphstruct = @{ $dirfiles{morphstruct} };
 	my @retcases = @{ $dirfiles{retcases} };
@@ -122,9 +122,9 @@ sub sim    # This function launch the simulations in ESP-r
 	my @descendcases = @{ $dirfiles{descendcases} };
 	my @descendstruct = @{ $dirfiles{descendstruct} };
 	
-	my $morphlist = $dirfiles{morphlist}; #say "dump(\$dat{morphlist}): " . dump($dat{morphlist});
+	my $morphlist = $dirfiles{morphlist}; 
 	my $morphblock = $dirfiles{morphblock};
-	my $simlist = $dirfiles{simlist}; #say "dump(\$simlist): " . dump($simlist);
+	my $simlist = $dirfiles{simlist}; 
 	my $simblock = $dirfiles{simblock};
 	my $retlist = $dirfiles{retlist};
 	my $retblock = $dirfiles{retblock};
@@ -133,9 +133,9 @@ sub sim    # This function launch the simulations in ESP-r
 	my $descendlist = $dirfiles{descendlist};
 	my $descendblock = $dirfiles{descendblock};
 	
-	my $skipfile = $vals{skipfile}; #say TOFILE "dump(\$skipfile): " . dump($skipfile);
-	my $skipsim = $vals{skipsim}; #say TOFILE "dump(\$skipsim): " . dump($skipsim);
-	my $skipreport = $vals{skipreport}; #say TOFILE "dump(\$skipreport): " . dump($skipreport);
+	my $skipfile = $vals{skipfile}; 
+	my $skipsim = $vals{skipsim}; 
+	my $skipreport = $vals{skipreport}; 
 	
 	#my $getpars = shift;
 	#eval( $getpars );
@@ -143,36 +143,36 @@ sub sim    # This function launch the simulations in ESP-r
 	#if ( fileno (MORPHLIST) 
 
 	my @container;
-	#say TOFILE "dump(\@instances): " . dump(@instances);
+	
 	my $countinstance = 0;
 	foreach my $instance (@instances)
 	{
 		my %d = %{$instance};
-		my $countcase = $d{countcase}; #say TOFILE "dump(\$countcase): " . dump($countcase);
-		my $countblock = $d{countblock}; #say TOFILE "dump(\$countblock): " . dump($countblock);
-		my @miditers = @{ $d{miditers} }; #say TOFILE "dump(\@miditers): " . dump(@miditers);
-		my @winneritems = @{ $d{winneritems} }; #say TOFILE "dumpIN( \@winneritems) " . dump(@winneritems);
-		my $countvar = $d{countvar}; #say TOFILE "dump(\$countvar): " . dump($countvar);
-		my $countstep = $d{countstep}; #say TOFILE "dump(\$countstep): " . dump($countstep);						
-		my $to = $d{to}; #say TOFILE "dump(\$to): " . dump($to);
-		my $origin = $d{origin}; #say TOFILE "dump(\$origin): " . dump($origin);
-		my @uplift = @{ $d{uplift} }; #say TOFILE "dump(\@uplift): " . dump(@uplift);
-		my @backvalues = @{ $d{backvalues} }; #say $tee "IN SIM \@backvalues " . dump(@backvalues);
-		my @sweeps = @{ $d{sweeps} }; #say $tee "dump(\@sweeps): " . dump(@sweeps);
-		my @sourcesweeps = @{ $d{sourcesweeps} }; #say $tee "dump(\@sourcesweeps): " . dump(@sourcesweeps);
+		my $countcase = $d{countcase}; 
+		my $countblock = $d{countblock}; 
+		my @miditers = @{ $d{miditers} }; 
+		my @winneritems = @{ $d{winneritems} }; 
+		my $countvar = $d{countvar}; 
+		my $countstep = $d{countstep}; 
+		my $to = $d{to}; 
+		my $origin = $d{origin}; 
+		my @uplift = @{ $d{uplift} }; 
+		my @backvalues = @{ $d{backvalues} }; 
+		my @sweeps = @{ $d{sweeps} }; 
+		my @sourcesweeps = @{ $d{sourcesweeps} }; 
 		#eval($getparshere);
 		
-		my $rootname = Sim::OPT::getrootname(\@rootnames, $countcase); #say TOFILE "dump(\$rootname): " . dump($rootname);
-		my @blockelts = Sim::OPT::getblockelts(\@sweeps, $countcase, $countblock); #say TOFILE "dumpIN( \@blockelts) " . dump(@blockelts);
-		my @blocks = Sim::OPT::getblocks(\@sweeps, $countcase);  #say TOFILE "dumpIN( \@blocks) " . dump(@blocks);
-		my $toitem = Sim::OPT::getitem(\@winneritems, $countcase, $countblock); #say TOFILE "dump(\$toitem): " . dump($toitem);
-		my $from = Sim::OPT::getline($toitem); #say TOFILE "dumpIN(\$from): " . dump($from);
-		my %varnums = Sim::OPT::getcase(\@varinumbers, $countcase); #say TOFILE "dumpIN---(\%varnums): " . dump(%varnums); 
-		my %mids = Sim::OPT::getcase(\@miditers, $countcase); #say TOFILE "dumpIN---(\%mids): " . dump(%mids); 
+		my $rootname = Sim::OPT::getrootname(\@rootnames, $countcase); 
+		my @blockelts = Sim::OPT::getblockelts(\@sweeps, $countcase, $countblock); 
+		my @blocks = Sim::OPT::getblocks(\@sweeps, $countcase);  
+		my $toitem = Sim::OPT::getitem(\@winneritems, $countcase, $countblock); 
+		my $from = Sim::OPT::getline($toitem); 
+		my %varnums = Sim::OPT::getcase(\@varinumbers, $countcase); 
+		my %mids = Sim::OPT::getcase(\@miditers, $countcase); 
 		#eval($getfly);
 		
-		my $stepsvar = Sim::OPT::getstepsvar($countvar, $countcase, \@varinumbers); #say TOFILE "dump(\$stepsvar): " . dump($stepsvar); 
-		my $varnumber = $countvar; #say TOFILE "dump---(\$varnumber): " . dump($varnumber) . "\n\n";  # LEGACY VARIABLE
+		my $stepsvar = Sim::OPT::getstepsvar($countvar, $countcase, \@varinumbers); 
+		my $varnumber = $countvar; 
 		
 		my @ress;
 		my @flfs;
@@ -188,16 +188,16 @@ sub sim    # This function launch the simulations in ESP-r
 		#	print SIMLIST "$to\n";
 		#}
 		
-		my $numberof_simtools = scalar ( keys %{ $dowhat{simtools} } ); #say TOFILE "\$numberof_simtools " . dump( $numberof_simtools );
+		my $numberof_simtools = scalar ( keys %{ $dowhat{simtools} } ); 
 		my $simelt = $to;
 		
 		my $counttool = 1;
 		while ( $counttool <= $numberof_simtools )
 		{	
-			my $skip = $vals{$countvar}{$counttool}{skip}; #say TOFILE "dumpinsim(\$skip): " . dump($skip);
+			my $skip = $vals{$countvar}{$counttool}{skip}; 
 			if ( not ( eval ( $skipsim{$counttool} )))
 			{
-				my $tooltype = $dowhat{simtools}{$counttool}; #say TOFILE "\$tooltype " . dump( $tooltype );
+				my $tooltype = $dowhat{simtools}{$counttool}; 
 				
 				if ( $tooltype eq "esp-r" )
 				{	
@@ -211,20 +211,20 @@ sub sim    # This function launch the simulations in ESP-r
 						$launchline = "-file $simelt\\cfg\\$fileconfig -mode script";
 					}
 					
-					#say TOFILE "dump(\%simtitles): " . dump( %simtitles ); 
-					#say TOFILE "dump(\$simtitles{\$counttool}): " . dump( $simtitles{$counttool} ); 
-					#say TOFILE "dump(\@{ \$simtitles{\$counttool}): " . dump( @{ $simtitles{$counttool} } ); 	
+					
+					
+					
 					my $countsim = 0;		
 					foreach my $simtitle_ref ( @{ $simtitles{$counttool} } )
 					{
-						my $date_to_sim = $simtitle_ref->[0]; #say TOFILE "dump(\$date_to_sim ): " . dump( $date_to_sim ); 
-						my $begin = $simtitle_ref->[1]; #say TOFILE "dump(\$begin): " . dump($begin); 
-						my $end = $simtitle_ref->[2]; #say TOFILE "dump(\$end): " . dump($end); 
-						my $before = $simtitle_ref->[3]; #say TOFILE "dump(\$before): " . dump($before); 
-						my $step = $simtitle_ref->[4]; #say TOFILE "dump(\$step): " . dump($step); 
+						my $date_to_sim = $simtitle_ref->[0]; 
+						my $begin = $simtitle_ref->[1]; 
+						my $end = $simtitle_ref->[2]; 
+						my $before = $simtitle_ref->[3]; 
+						my $step = $simtitle_ref->[4]; 
 						
-						my $resfile = "$simelt-$date_to_sim-$tooltype.res"; #say TOFILE "dump(\$resfile): " . dump($resfile); 
-						my $flfile = "$simelt-$date_to_sim-$tooltype.fl"; #say TOFILE "dump(\$flfile): " . dump($flfile); 
+						my $resfile = "$simelt-$date_to_sim-$tooltype.res"; 
+						my $flfile = "$simelt-$date_to_sim-$tooltype.fl"; 
 
 						#if ( fileno (SIMLIST) )
 						#if (not (-e $simlist ) )
@@ -252,15 +252,15 @@ sub sim    # This function launch the simulations in ESP-r
 							}
 						}
 						
-						#say "INSIM1\$countcase : " . dump($countcase);
-						#say "INSIM1\@rootnames : " . dump(@rootnames);
-						#say "INSIM1\$countblock : " . dump($countblock);
-						#say "INSIM1\@sweeps : " . dump(@sweeps);
-						#say "INSIM1\@varinumbers : " . dump(@varinumbers);
-						#say "INSIM1\@miditers : " . dump(@miditers);
-						#say "INSIM1\@winneritems : " . dump(@winneritems);
-						#say "INSIM1\@morphcases : " . dump(@morphcases);
-						#say "INSIM1\@morphstruct : " . dump(@morphstruct);
+						
+						
+						
+						
+						
+						
+						
+						
+						
 						
 						push ( @{ $simstruct[ $countcase ][ $countblock ][ $countinstance ][$counttool] }, $resfile );
 						print SIMBLOCK "$resfile\n";
@@ -354,38 +354,38 @@ $printthis
 					my $countsim = 0;			
 					foreach my $simtitle_ref ( @{ $simtitles{$counttool} } )
 					{
-						my $date_to_sim = $simtitle_ref->[0]; #say TOFILE "dump(\$date_to_sim ): " . dump( $date_to_sim ); 
-						my $begin = $simtitle_ref->[1]; #say TOFILE "dump(\$begin): " . dump($begin); 
-						my $end = $simtitle_ref->[2]; #say TOFILE "dump(\$end): " . dump($end); 
-						my $before = $simtitle_ref->[3]; #say TOFILE "dump(\$before): " . dump($before); 
-						my $step = $simtitle_ref->[4]; #say TOFILE "dump(\$step): " . dump($step); 
+						my $date_to_sim = $simtitle_ref->[0]; 
+						my $begin = $simtitle_ref->[1]; 
+						my $end = $simtitle_ref->[2]; 
+						my $before = $simtitle_ref->[3]; 
+						my $step = $simtitle_ref->[4]; 
 						 
-						my $epw = $simtitle_ref->[5]; #say TOFILE "dump(\$epw ): " . dump( $epw ); 
-						my $epwfile = $mypath . "/" . $epw; #say TOFILE"\$epwfile " . dump( $epwfile );
-						my $epdir = $simtitle_ref->[6]; #say TOFILE "dump(\$epdir ): " . dump( $epdir ); 
-						my $epoldfile = $simtitle_ref->[7]; #say TOFILE "dump(\$epoldfile ): " . dump( $epoldfile ); 
-						my $epnewfragment = $simtitle_ref->[8]; #say TOFILE "dump(\$epnewfragment ): " . dump( $epnewfragment );  
-						my $outputdir = $simtitle_ref->[9]; #say TOFILE "dump(\$outputdir ): " . dump( $outputdir ); 
-						my $modfiletype = $simtitle_ref->[10]; #say TOFILE "dump(\$modfiletype ): " . dump( $modfiletype ); 
-						my $resfiletype = $simtitle_ref->[11]; #say TOFILE "dump(\$resfiletype ): " . dump( $resfiletype ); 
-						my $epoldpath = $to . $epdir . "/" . $epoldfile; #say TOFILE "dump(\$epoldpath ): " . dump( $epoldpath ); 
+						my $epw = $simtitle_ref->[5]; 
+						my $epwfile = $mypath . "/" . $epw; 
+						my $epdir = $simtitle_ref->[6]; 
+						my $epoldfile = $simtitle_ref->[7]; 
+						my $epnewfragment = $simtitle_ref->[8]; 
+						my $outputdir = $simtitle_ref->[9]; 
+						my $modfiletype = $simtitle_ref->[10]; 
+						my $resfiletype = $simtitle_ref->[11]; 
+						my $epoldpath = $to . $epdir . "/" . $epoldfile; 
 						my $tempname = $to;
-						$tempname =~ s/$mypath\/// ; #say TOFILE "dump(\$tempname ): " . dump( $tempname ); 
-						my $epnewfile = $tempname . $epnewfragment . "$modfiletype"; #say TOFILE "dump(\$epnewfile ): " . dump( $epnewfile ); 
-						my $epresroot = $tempname . $epnewfragment ; #say TOFILE "dump(\$epnewfile ): " . dump( $epnewfile ); 
+						$tempname =~ s/$mypath\/// ; 
+						my $epnewfile = $tempname . $epnewfragment . "$modfiletype"; 
+						my $epresroot = $tempname . $epnewfragment ; 
 						
 						my $epnewpath;
 						unless ( ( "$^O" eq "MSWin32" ) or ( "$^O" eq "MSWin64" ) ) 
 						{ 
-							$epnewpath = $to . $epdir . "/" . $epnewfile; #say TOFILE "dump(\$epnewpath ): " . dump( $epnewpath ); 
+							$epnewpath = $to . $epdir . "/" . $epnewfile; 
 						}
 						else
 						{ 
-							$epnewpath = $to . $epdir . "\\" . $epnewfile; #say TOFILE "dump(\$epnewpath ): " . dump( $epnewpath ); 
+							$epnewpath = $to . $epdir . "\\" . $epnewfile; 
 						}
 						
 						my @simdos = @{ $simtitle_ref };
-						my @changes = @simdos[ 12..$#simdos ]; #say TOFILE "dump(\@changes ): " . dump( @changes ); 
+						my @changes = @simdos[ 12..$#simdos ]; 
 						if ( $tooltype eq "energyplus" ) # RESTORES DEFAULTS FOR ENERGYPLUS
 						{
 							unless ( ( "$^O" eq "MSWin32" ) or ( "$^O" eq "MSWin64" ) ) 
@@ -405,7 +405,7 @@ $printthis
 						
 						open ( EPOLDPATH, "$epoldpath" ) or die( "$!" );
 						my @sourcecontents = <EPOLDPATH>;
-						close EPOLDPATH; #say TOFILE "dump(\@sourcecontents ): " . dump( @sourcecontents ); 
+						close EPOLDPATH; 
 						
 						unless ( -e $epnewpath )
 						{
@@ -414,9 +414,9 @@ $printthis
 							{
 								foreach my $change ( @changes )
 								{
-									my $source = $change->[0]; #say T say TOFILE "dump(\$source ): " . dump( $source ); 
-									my $target = $change->[1]; #say TOFILE "dump(\$target ): " . dump( $target ); say TOFILE "dump(\$rowBEFORE ): " . dump( $row ); 
-									$row =~ s/$source/$target/ ; #say TOFILE "dump(\$rowAFTER ): " . dump( $row ); 
+									my $source = $change->[0]; 
+									my $target = $change->[1]; 
+									$row =~ s/$source/$target/ ; 
 								}
 								print EPNEWPATH $row;
 
@@ -424,18 +424,18 @@ $printthis
 							close EPNEWPATH;
 						}
 						
-						my $file_eplus = "$to/$file_eplus";  #say TOFILE "dump(\$file_eplus ): " . dump( $file_eplus ); 
+						my $file_eplus = "$to/$file_eplus";  
 						
-						my $simelt = $mypath . "$outputdir"; #say TOFILE "dump(\$simelt ): " . dump( $simelt ); 
+						my $simelt = $mypath . "$outputdir"; 
 						
 						my $resfile;
 						unless ( ( "$^O" eq "MSWin32" ) or ( "$^O" eq "MSWin64" ) ) 
 						{
-							$resfile = "$simelt/$epresroot$resfiletype"; #say TOFILE "dump(\$resfile ): " . dump( $resfile ); 
+							$resfile = "$simelt/$epresroot$resfiletype"; 
 						}
 						else
 						{
-							$resfile = "$simelt\\$epresroot$resfiletype"; #say TOFILE "dump(\$resfile ): " . dump( $resfile ); 
+							$resfile = "$simelt\\$epresroot$resfiletype"; 
 						}
 						
 						
@@ -513,17 +513,17 @@ $printthis
 									unless ( $exeonfiles eq "n" )
 										{
 										
-										my $tempf = $epnewpath; #say TOFILE "dump(\$tempf1 ): " . dump( $tempf );
+										my $tempf = $epnewpath; 
 										unless ( ( "$^O" eq "MSWin32" ) or ( "$^O" eq "MSWin64" ) ) 
 										{
-											$tempf =~ s/$to$epdir\///;  #say TOFILE "dump(\$tempf2 ): " . dump( $tempf ); 
-											$templaunch = $mypath . "/" . $tempf; #say TOFILE "dump(\$templaunch ): " . dump( $templaunch ); 
+											$tempf =~ s/$to$epdir\///;  
+											$templaunch = $mypath . "/" . $tempf; 
 											`cp -f $epnewpath $templaunch`;
 										}
 										else
 										{
-											$tempf =~ s/$to$epdir\\//;  #say TOFILE "dump(\$tempf2 ): " . dump( $tempf ); 
-											$templaunch = $mypath . "\\" . $tempf; #say TOFILE "dump(\$templaunch ): " . dump( $templaunch ); 
+											$tempf =~ s/$to$epdir\\//;  
+											$templaunch = $mypath . "\\" . $tempf; 
 											`xcopy  /e /c /r /y $epnewpath $templaunch`;
 										}
 										`runenergyplus $templaunch $epwfile`;
@@ -538,7 +538,7 @@ $printthis
 										print TOFILE "xcopy  /e /c /r /y $epnewpath $templaunch\n";
 									}
 									print TOFILE "runenergyplus $templaunch $epwfile\n";
-									#print TOFILE "rm -f $templaunch\n";
+									
 									say "#Simulating case " . ($countcase + 1) . ", block " . ($countblock + 1) . ", parameter $countvar at iteration $countstep for tool $tooltype. Instance $countinstance: using $epnewpath (actually $templaunch) to obtain $resfile. " ;										
 								}
 							}	
@@ -553,8 +553,8 @@ $printthis
 	}
 	close SIMLIST;
 	close SIMBLOCK;
-	#say TOFILE "dump(\@simcases ): " . dump( @simcases ); 
-	#say TOFILE "dump(\@simstruct ): " . dump( @simstruct ); 
+	
+	
 	return ( \@simcases, \@simstruct );
 	close TOFILE;
 	close OUTFILE;
